import Paper from '@mui/material/Paper';
import UsersTasksTableToolbar from '../../components/UsersTasksCompoments/UsersTasksTableToolbar/UsersTasksTableToolbar';
import UsersTasksTablePagination from '../../components/UsersTasksCompoments/UsersTasksTablePagination/UsersTasksTablePagination';
import UsersTasksTableContainer from '../../components/UsersTasksCompoments/UsersTasksTableContainer/UsersTasksTableContainer';
import { fetchAllTasksByMembership } from '../../store/actions/tasksActions';
import { shallowEqual, useDispatch, useSelector } from 'react-redux';
import { useEffect, useState } from 'react';

export default function EnhancedTable() {
  const dispatch = useDispatch();

  const {tasks} = useSelector((state) => state.tasks, shallowEqual);
  const projects = useSelector((state) => state.tasks.projects);
  const user = useSelector((state) => state.users.user);

  const [order, setOrder] = useState('asc');
  const [orderBy, setOrderBy] =useState('createdAt');
  const [page, setPage] = useState(0);
  const [rowsPerPage, setRowsPerPage] = useState(10);
  const [addFormStatus, setAddFormStatus] = useState(false);

  useEffect(() => {
    dispatch(fetchAllTasksByMembership());
  }, [dispatch]);

  const handleRequestSort = (event, property) => {
    const isAsc = orderBy === property && order === 'asc';
    setOrder(isAsc ? 'desc' : 'asc');
    setOrderBy(property);
  };

  const handleChangePage = (event, newPage) => {
    setPage(newPage);
  };

  const handleChangeRowsPerPage = (event) => {
    setRowsPerPage(parseInt(event.target.value, 10));
    setPage(0);
  };

  const createTaskFromButtonHandler = () => {
    setAddFormStatus((prevState)=>{return !prevState})
  }

  return (
    <Paper sx={{ width: '100%', mb: 2 }}>
      <UsersTasksTableToolbar 
         addFormStatus={addFormStatus} 
         createTaskFromButtonHandler={createTaskFromButtonHandler}
      />
      <UsersTasksTableContainer
        order={order}
        orderBy={orderBy}
        handleRequestSort={handleRequestSort}
        rows={tasks}
        page={page}
        rowsPerPage={rowsPerPage}
        addFormStatus={addFormStatus}
      />
      <UsersTasksTablePagination
        count={tasks.length}
        rowsPerPage={rowsPerPage}
        page={page}
        handleChangePage={handleChangePage}
        handleChangeRowsPerPage={handleChangeRowsPerPage}
      />
    </Paper>
  );
}
